using System;
using System.Collections.Generic;
using Server;
using Server.Multis;
using Server.Network;

namespace Server.Items
{

	[Furniture]
	[Flipable( 0xE42, 0xE43 )]
	public class Chest_01 : BaseContainer
	{

	public override int DefaultGumpID{ get{ return 0x49; } } //Wooden Chest Gump

		[Constructable]
		public Chest_01() : base( 0xE42 )
		{
			Name = "Chest";
			Weight = 1.0;
		}

		public override void DisplayTo( Mobile m )
		{
			if ( DynamicFurniture_Chest_1.Open( this, m ) )
				base.DisplayTo( m );
		}

		public Chest_01( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();

			DynamicFurniture_Chest_1.Close( this );
		}
	}


	public class DynamicFurniture_Chest_1
	{
		private static Dictionary<Container, Timer> m_Table = new Dictionary<Container, Timer>();

		public static bool Open( Container c, Mobile m )
		{
			if ( m_Table.ContainsKey( c ) )
			{
				c.SendRemovePacket();
				Close( c );
				c.Delta( ItemDelta.Update );
				c.ProcessDelta();
				return false;
			}

			if ( c is Chest_01 )
			{
				Timer t = new FurnitureTimer_Chest_1( c, m );
				t.Start();
				m_Table[c] = t;

				switch ( c.ItemID )
				{
					case 0xE42: c.ItemID = 0x3C19; break;	//Chest Open
					case 0xE43: c.ItemID = 0x3C1A; break;	//Chest Open
				}
			}

			return true;
		}

		public static void Close( Container c )
		{
			Timer t = null;

			m_Table.TryGetValue( c, out t );

			if ( t != null )
			{
				t.Stop();
				m_Table.Remove( c );
			}

			if ( c is Chest_01 )
			{
				switch ( c.ItemID )
				{
					case 0x3C19: c.ItemID = 0xE42; break;	//Chest Close
					case 0x3C1A: c.ItemID = 0xE43; break;	//Chest Close
				}
			}
		}
	}

	public class FurnitureTimer_Chest_1 : Timer
	{
		private Container m_Container;
		private Mobile m_Mobile;

		public FurnitureTimer_Chest_1( Container c, Mobile m ) : base( TimeSpan.FromSeconds( 0.5 ), TimeSpan.FromSeconds( 0.5 ) )
		{
			Priority = TimerPriority.TwoFiftyMS;

			m_Container = c;
			m_Mobile = m;
		}

		protected override void OnTick()
		{
			if ( m_Mobile.Map != m_Container.Map || !m_Mobile.InRange( m_Container.GetWorldLocation(), 3 ) )
				DynamicFurniture_Chest_1.Close( m_Container );
		}
	}
}