using System;
using System.Collections.Generic;
using Server;
using Server.Multis;
using Server.Network;

namespace Server.Items
{

	[Furniture]
	[Flipable( 0xE40, 0xE41 )]
	public class Chest_02 : BaseContainer
	{

	public override int DefaultGumpID{ get{ return 0x42; } } //Metal Chest Gold Rim Gump

		[Constructable]
		public Chest_02() : base( 0xE40 )
		{
			Name = "Chest";
			Weight = 1.0;
		}

		public override void DisplayTo( Mobile m )
		{
			if ( DynamicFurniture_Chest_2.Open( this, m ) )
				base.DisplayTo( m );
		}

		public Chest_02( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();

			DynamicFurniture_Chest_2.Close( this );
		}
	}


	public class DynamicFurniture_Chest_2
	{
		private static Dictionary<Container, Timer> m_Table = new Dictionary<Container, Timer>();

		public static bool Open( Container c, Mobile m )
		{
			if ( m_Table.ContainsKey( c ) )
			{
				c.SendRemovePacket();
				Close( c );
				c.Delta( ItemDelta.Update );
				c.ProcessDelta();
				return false;
			}

			if ( c is Chest_02 )
			{
				Timer t = new FurnitureTimer_Chest_2( c, m );
				t.Start();
				m_Table[c] = t;

				switch ( c.ItemID )
				{
					case 0xE40: c.ItemID = 0x3C1D; break;	//Chest Open  0xE40 = Closed Chest East ... 0x3C1D = Open Chest Image East
					case 0xE41: c.ItemID = 0x3C1E; break;	//Chest Open  0xE41 = Closed Chest South ... 0x3C1E = Open Chest Image South
				}
			}

			return true;
		}

		public static void Close( Container c )
		{
			Timer t = null;

			m_Table.TryGetValue( c, out t );

			if ( t != null )
			{
				t.Stop();
				m_Table.Remove( c );
			}

			if ( c is Chest_02 )
			{
				switch ( c.ItemID )
				{
					case 0x3C1D: c.ItemID = 0xE40; break;	//Chest Close  0x3C1D = Open Chest Image East ... 0xE40 = Closed Chest East
					case 0x3C1E: c.ItemID = 0xE41; break;	//Chest Close  0x3C1E = Open Chest Image South ... 0xE41 = Closed Chest South
				}
			}
		}
	}

	public class FurnitureTimer_Chest_2 : Timer
	{
		private Container m_Container;
		private Mobile m_Mobile;

		public FurnitureTimer_Chest_2( Container c, Mobile m ) : base( TimeSpan.FromSeconds( 0.5 ), TimeSpan.FromSeconds( 0.5 ) )
		{
			Priority = TimerPriority.TwoFiftyMS;

			m_Container = c;
			m_Mobile = m;
		}

		protected override void OnTick()
		{
			if ( m_Mobile.Map != m_Container.Map || !m_Mobile.InRange( m_Container.GetWorldLocation(), 3 ) )
				DynamicFurniture_Chest_2.Close( m_Container );
		}
	}
}